aboutsummaryrefslogtreecommitdiffstats
path: root/mpfr.c
diff options
context:
space:
mode:
authorArnold D. Robbins <arnold@skeeve.com>2016-11-12 19:12:13 +0200
committerArnold D. Robbins <arnold@skeeve.com>2016-11-12 19:12:13 +0200
commitcc04afb329cea035d0d9b67cd3b677e06b2f3996 (patch)
tree3622f3f241d75079bcafd24651a4952e357a9c09 /mpfr.c
parent9a31c12053ef715ccb732f456de00b4afc38d888 (diff)
downloadegawk-cc04afb329cea035d0d9b67cd3b677e06b2f3996.tar.gz
egawk-cc04afb329cea035d0d9b67cd3b677e06b2f3996.tar.bz2
egawk-cc04afb329cea035d0d9b67cd3b677e06b2f3996.zip
Further code improvements and doc changes as diff until merge.
Diffstat (limited to 'mpfr.c')
-rw-r--r--mpfr.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpfr.c b/mpfr.c
index b24c89fd..ddf020dd 100644
--- a/mpfr.c
+++ b/mpfr.c
@@ -348,13 +348,13 @@ mpg_force_number(NODE *n)
n->flags |= NUMCUR;
if (force_mpnum(n, (do_non_decimal_data && ! do_traditional), true)) {
- if ((n->flags & MAYBE_NUM) != 0) {
- /* leave MAYBE_NUM set to indicate a strnum */
+ if ((n->flags & USER_INPUT) != 0) {
+ /* leave USER_INPUT set to indicate a strnum */
n->flags &= ~STRING;
n->flags |= NUMBER;
}
} else
- n->flags &= ~MAYBE_NUM;
+ n->flags &= ~USER_INPUT;
return n;
}